pub struct ExecArgs {
pub silent: bool,
pub verbose: u8,
pub batch: bool,
pub gui: bool,
pub inherent: bool,
pub assume_inherent: bool,
pub property: Option<String>,
pub strategy: ExecStrategy,
}Expand description
Arguments for executing machine-check.
Fields
silent: boolWhether the execution should be completely silent.
This will prevent standard logging to stderr and writing the result to stdout.
verbose: u8Adds debug and trace messages depending of the number of flags used.
batch: boolOutputs the result to stdout in a machine-readable format.
The format is not stabilised yet.
gui: boolOpens the Graphical User Interface.
The gui feature of machine-check must be enabled for this to work.
inherent: boolVerifies the inherent property.
assume_inherent: boolAssumes that the inherent property holds.
The verification result will be meaningless if it does not.
property: Option<String>Verifies a given property.
It will be first verified that the inherent property holds unless assume_inherent is given.
strategy: ExecStrategyThe verification strategy.