pub trait Ext<const X: u32> {
type Output;
// Required method
fn ext(self) -> Self::Output;
}Expand description
Bitvector extension / narrowing trait.
The amount of bits in the result is given by the generic parameter X.
If X is greater than original number of bits, the bitvector is extended according to its type.
If X is lesser than original number of bits, the highest bits of bitvector are dropped.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".